<?php

/**
 * @package Opening Shortly Lite
 */


if (!function_exists('wp_body_open')) {

    function wp_body_open() {
        do_action('wp_body_open');
    }

}

function opening_shortly_lite_embed_html($html) {
    return '<div class="video-container">' . $html . '</div>';
}

add_filter('embed_oembed_html', 'opening_shortly_lite_embed_html', 10, 3);
add_filter('video_embed_html', 'opening_shortly_lite_embed_html');

function opening_shortly_lite_sanitize_phone_number($phone) {
    return preg_replace('/[^\d+]/', '', $phone);
}



if (!function_exists('opening_shortly_lite_setup')) :

    function opening_shortly_lite_setup() {
        add_theme_support('automatic-feed-links');
        add_theme_support('woocommerce');
        add_theme_support('post-thumbnails');
        add_theme_support('custom-header');
        add_theme_support('title-tag');
        add_theme_support("wp-block-styles");
        add_theme_support("responsive-embeds");
        add_theme_support("align-wide");
        add_theme_support('custom-background', array(
            'default-color' => '000000',
            'default-image' => get_template_directory_uri() . '/frontskin/images/opening-shortly-bg.jpg',
        ));

        $defaults = array(
            'default-image'      => '',
            'default-text-color' => '0065b3',
            'width'              => 1400,
            'height'             => 500,
            'uploads'            => true,
            'wp-head-callback'   => 'opening_shortly_lite_header_style',
        );
        add_theme_support('custom-header', $defaults);

        //custom logo
        $opening_shortly_lite_custom_logo = array(
            'height'      => 56,
            'width'       => 224,
            'flex-height' => true,
            'flex-width'  => true,
            'header-text' => array('site-title', 'site-description'),
        );
        add_theme_support('custom-logo', $opening_shortly_lite_custom_logo);
        add_image_size('opening-shortly-lite-home-box-size', 400, 250, true);

        /**
         * Add post-formats support.
         */
        add_theme_support(
                'post-formats',
                array(
                    'link',
                    'aside',
                    'gallery',
                    'image',
                    'quote',
                    'status',
                    'video',
                    'audio',
                    'chat',
                )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
                'html5',
                array(
                    'comment-form',
                    'comment-list',
                    'gallery',
                    'caption',
                    'style',
                    'script',
                    'navigation-widgets',
                )
        );

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        // Add support for Block Styles.
        add_theme_support('wp-block-styles');

        // Add support for full and wide align images.
        add_theme_support('align-wide');

        // Add support for responsive embedded content.
        add_theme_support('responsive-embeds');

        // Add support for custom line height controls.
        add_theme_support('custom-line-height');

        // Add support for experimental link color control.
        add_theme_support('experimental-link-color');

        // Add support for experimental cover block spacing.
        add_theme_support('custom-spacing');

        // Add support for custom units.
        // This was removed in WordPress 5.6 but is still required to properly support WP 5.5.
        add_theme_support('custom-units');

        add_theme_support('jetpack-content-options', array(
            'blog-display'       => 'content', // the default setting of the theme: 'content', 'excerpt' or array( 'content', 'excerpt' ) for themes mixing both display.
            'author-bio'         => true, // display or not the author bio: true or false.
            'author-bio-default' => false, // the default setting of the author bio, if it's being displayed or not: true or false (only required if false).
            'masonry'            => '.site-main', // a CSS selector matching the elements that triggers a masonry refresh if the theme is using a masonry layout.
            'post-details'       => array(
                'stylesheet' => 'themeslug-style', // name of the theme's stylesheet.
                'date'       => '.posted-on', // a CSS selector matching the elements that display the post date.
                'categories' => '.cat-links', // a CSS selector matching the elements that display the post categories.
                'tags'       => '.tags-links', // a CSS selector matching the elements that display the post tags.
                'author'     => '.byline', // a CSS selector matching the elements that display the post author.
                'comment'    => '.comments-link', // a CSS selector matching the elements that display the comment link.
            ),
            'featured-images'    => array(
                'archive'         => true, // enable or not the featured image check for archive pages: true or false.
                'archive-default' => false, // the default setting of the featured image on archive pages, if it's being displayed or not: true or false (only required if false).
                'post'            => true, // enable or not the featured image check for single posts: true or false.
                'post-default'    => false, // the default setting of the featured image on single posts, if it's being displayed or not: true or false (only required if false).
                'page'            => true, // enable or not the featured image check for single pages: true or false.
                'page-default'    => false, // the default setting of the featured image on single pages, if it's being displayed or not: true or false (only required if false).
            ),
        ));

        add_theme_support('html5', array('comment-list', 'comment-form', 'search-form', 'gallery', 'caption', 'style', 'script'));

        add_editor_style(trailingslashit(get_template_directory_uri()) . '/frontskin/css/editor-style.css');
    }

endif; // opening_shortly_lite_setup
add_action('after_setup_theme', 'opening_shortly_lite_setup');

function opening_shortly_lite_style() {
    wp_enqueue_style('opening-shortly-lite-basic-style', get_stylesheet_uri());
    wp_enqueue_style('bootstrapcss', get_template_directory_uri() . '/bootstrap/css/bootstrap.css');
    wp_enqueue_script('bootstrapjs', get_template_directory_uri() . '/bootstrap/js/bootstrap.js', array('jquery'));
    wp_enqueue_style('opening-shortly-lite-style', get_template_directory_uri() . '/frontskin/css/opening-shortly-lite-main.css');
    wp_enqueue_style('opening-shortly-lite-responsive', get_template_directory_uri() . '/frontskin/css/opening-shortly-lite-responsive.css');
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/frontskin/css/font-awesome.css');
    wp_enqueue_script('opening-shortly-lite-customjs', get_template_directory_uri() . '/frontskin/js/opening-shortly-lite-customjs.js', array('jquery'));
}

add_action('wp_enqueue_scripts', 'opening_shortly_lite_style');

if (!function_exists('opening_shortly_lite_the_custom_logo')) :

    function opening_shortly_lite_the_custom_logo() {
        the_custom_logo();
    }

endif;

function opening_shortly_lite_header_style() {
    $opening_shortly_lite_header_text_color = get_header_textcolor();

    if (get_theme_support('custom-header', 'default-text-color') === $opening_shortly_lite_header_text_color) {
        return;
    }
    echo '<style id="opening-shortly-lite-custom-header-styles" type="text/css">';
    if ('blank' !== $opening_shortly_lite_header_text_color) {
        echo '.header_top .logo a,
            .blog-post h3 a,
            .blog-post .pageheading h1
			 {
				color: #' . esc_attr($opening_shortly_lite_header_text_color) . '
			}';
    }
    echo '</style>';
}

add_action('customize_register', 'opening_shortly_lite_customize_register_custom_controls', 9);
function opening_shortly_lite_customize_register_custom_controls() {
    get_template_part('core/opening_shortly_lite', 'sectionpro');
}